use Test::Exception;
use PDL::IO::RDB qw( rdrdb );
use Number::Format qw( round );

# test std dev error calculation
sub test_std_dev_errs {

    my $spec = shift;

    my $img    = File::Temp->new( DIR => '.', SUFFIX => '.fits' );
    my $output = File::Temp->new( DIR => '.', UNLINK => 1, SUFFIX => '.rdb' );

    my $data = grandom( 100, 100 );
    $data->wfits($img);

    @ARGV = ( "--bin=$spec", "--outfile=$output", '--output-all-bins', $img->filename, 50, 50 );

    my $pfx = "std dev errs";

    lives_ok { main() } "$pfx: execute";

    my %rdb = rdrdb( $output->filename );

    my ($mean,$prms,$median,$min,$max,$adev,$rms) = $data->stats;

    is( $rdb{sum}->nelem, 1, "$pfx: number of bins" );

    isfuzz( $rdb{sum}->sclr, $data->dsum, "$pfx: sum",2 );

    isfuzz( $rdb{sb}->sclr, $data->sum / $data->nelem, "$pfx: sb" );

    isfuzz( $rdb{sb_err}->sclr, ($rms->sclr / $data->nelem), "$pfx: sberr" );
}

sub isfuzz {

    my ( $a, $b, $label, $precision ) = @_;

    $precision ||= 4;

    return 
      is ( round($a, $precision),
           round($b, $precision),
           $label );
}


1;
